@@ -28,6 +28,7 @@ __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 from . import mathsymbols
+from . import orca_state
 from .orca_i18n import _
 
 # chnames is a dictionary where the keys represent a unicode character
@@ -626,6 +627,10 @@ chnames['\u2032'] = _("prime")
 #
 chnames['\u2033'] = _("double prime")
 
+# Translators: this is the spoken word for the character '‴' (U+2034)
+#
+chnames['\u2034'] = _("triple prime")
+
 # Translators: this is the spoken word for the character '⁃' (U+2043)
 #
 chnames['\u2043'] = _("hyphen bullet")
@@ -795,7 +800,7 @@ chnames['\ue00c'] = _("black diamond")
 #
 chnames['\ufffc'] = _("object replacement character")
 
-def getCharacterName(character):
+def getCharacterName(character, preferMath=False):
     """Given a character, return its name as people might refer to it
     in ordinary conversation.
 
@@ -806,7 +811,14 @@ def getCharacterName(character):
     """
 
     mathName = mathsymbols.getCharacterName(character)
-    if mathName:
+    charName = chnames.get(character)
+    if not (charName or mathName):
+        return character
+    if mathName and (not charName or preferMath):
+        return mathName
+    if charName and not mathName:
+        return charName
+    if orca_state.activeScript and orca_state.activeScript.utilities.isInMath():
         return mathName
 
-    return chnames.get(character, character)
+    return charName
