@@ -486,6 +486,9 @@ class Generator:
     def _generateHasLongDesc(self, obj, **args):
         return []
 
+    def _generateHasPopup(self, obj, **args):
+        return []
+
     def _generateAvailability(self, obj, **args):
         """Returns an array of strings for use by speech and braille that
         represent the grayed/sensitivity/availability state of the
@@ -1003,6 +1006,21 @@ class Generator:
 
         return [displayedText]
 
+    def _generateListItemMarker(self, obj, **args):
+        startOffset = args.get('startOffset', 0)
+        if not (0 <= startOffset <= 1):
+            return []
+
+        endOffset = args.get('endOffset')
+        if endOffset is not None and endOffset == startOffset:
+            return []
+
+        listItemMarker = self._script.utilities.getListItemMarkerText(obj)
+        if listItemMarker:
+            return [listItemMarker]
+
+        return []
+
     #####################################################################
     #                                                                   #
     # Tree interface information                                        #
