@@ -379,31 +379,6 @@ class Script:
 
         return skip
 
-    def checkKeyboardEventData(self, keyboardEvent):
-        """Checks the data on the keyboard event.
-
-        Some toolkits don't fill all the key event fields, and/or fills
-        them out with unexpected data. This method tries to fill in the
-        missing fields and validate/standardize the data we've been given.
-        While any script can override this method, it is expected that
-        this will only be done at the toolkit script level.
-
-        Arguments:
-        - keyboardEvent: an instance of input_event.KeyboardEvent
-        """
-
-        try:
-            from gi.repository import Gdk
-            keyboardEvent.keyval_name = Gdk.keyval_name(keyboardEvent.id)
-        except:
-            msg = 'ERROR: Exception getting keyval_name for id: %d' % keyboardEvent.id
-            debug.println(debug.LEVEL_INFO, msg, True)
-        else:
-            if keyboardEvent.event_string == '':
-                msg = 'INFO: Setting event_string to: %s' % keyboardEvent.keyval_name
-                debug.println(debug.LEVEL_INFO, msg, True)
-                keyboardEvent.event_string = keyboardEvent.keyval_name
-
     def consumesKeyboardEvent(self, keyboardEvent):
         """Called when a key is pressed on the keyboard.
 
@@ -542,6 +517,11 @@ class Script:
         """
         return True
 
+    def forceScriptActivation(self, event):
+        """Allows scripts to insist that they should become active."""
+
+        return False
+
     def activate(self):
         """Called when this script is activated."""
         pass
