@@ -887,15 +887,20 @@ class Script(default.Script):
         priorObj = args.get("priorObj")
         if self._lastCommandWasCaretNav or args.get("includeContext"):
             priorObj, priorOffset = self.utilities.getPriorContext()
+            args["priorObj"] = priorObj
 
         if obj.getRole() == pyatspi.ROLE_ENTRY:
-            utterances = self.speechGenerator.generateSpeech(obj, priorObj=priorObj)
+            utterances = self.speechGenerator.generateSpeech(obj, **args)
             speech.speak(utterances)
             self.updateBraille(obj)
             return
 
+        # We shouldn't use cache in this method, because if the last thing we presented
+        # included this object and offset (e.g. a Say All or Mouse Review), we're in
+        # danger of presented irrelevant context.
+        useCache = False
         offset = args.get("offset", 0)
-        contents = self.utilities.getObjectContentsAtOffset(obj, offset)
+        contents = self.utilities.getObjectContentsAtOffset(obj, offset, useCache)
         self.displayContents(contents)
         self.speakContents(contents, **args)
  
@@ -1236,7 +1241,7 @@ class Script(default.Script):
         speech.speak(utterances)
         self._saveFocusedObjectInfo(newFocus)
 
-        if self.utilities.inTopLevelWebApp(newFocus):
+        if self.utilities.inTopLevelWebApp(newFocus) and not self._browseModeIsSticky:
             announce = not self.utilities.inDocumentContent(oldFocus)
             self.enableStickyFocusMode(None, announce)
             return True
@@ -1293,6 +1298,12 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return False
 
+        if event.source.getRole() != pyatspi.ROLE_DOCUMENT_WEB \
+           and not self.utilities.isOrDescendsFrom(orca_state.locusOfFocus, event.source):
+            msg = "WEB: Ignoring: Not document and not something we're in"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
         self.structuralNavigation.clearCache()
 
         if self.utilities.getDocumentForObject(event.source.parent):
@@ -2142,6 +2153,11 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
+        if self.utilities.eventIsSpinnerNoise(event):
+            msg = "WEB: Ignoring: Event believed to be spinner noise"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
         if self.utilities.textEventIsForNonNavigableTextObject(event):
             msg = "WEB: Ignoring event for non-navigable text object"
             debug.println(debug.LEVEL_INFO, msg, True)
