@@ -104,7 +104,35 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         # call utility methods rather than generate it.
         return super()._generateAnyTextSelection(obj, **args)
 
+    def _generateHasPopup(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
+        if not self._script.utilities.inDocumentContent(obj):
+            return []
+
+        result = []
+        popupType = self._script.utilities.popupType(obj)
+        if popupType == 'dialog':
+            result = [messages.HAS_POPUP_DIALOG]
+        elif popupType == 'grid':
+            result = [messages.HAS_POPUP_GRID]
+        elif popupType == 'listbox':
+            result = [messages.HAS_POPUP_LISTBOX]
+        elif popupType in ('menu', 'true'):
+            result = [messages.HAS_POPUP_MENU]
+        elif popupType == 'tree':
+            result = [messages.HAS_POPUP_TREE]
+
+        if result:
+            result.extend(self.voice(speech_generator.SYSTEM))
+
+        return result
+
     def _generateClickable(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
         if not self._script.utilities.inDocumentContent(obj):
             return []
 
@@ -120,6 +148,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return []
 
     def _generateDescription(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
         if not self._script.utilities.inDocumentContent(obj):
             return super()._generateDescription(obj, **args)
 
@@ -133,7 +164,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if obj != orca_state.locusOfFocus:
             if role in [pyatspi.ROLE_ALERT, pyatspi.ROLE_DIALOG]:
                 return super()._generateDescription(obj, **args)
-            return []
+            if not args.get('inMouseReview'):
+                return []
 
         formatType = args.get('formatType')
         if formatType == 'basicWhereAmI' and self._script.utilities.isLiveRegion(obj):
@@ -149,6 +181,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return super()._generateDescription(obj, **args)
 
     def _generateHasLongDesc(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
         if not self._script.utilities.inDocumentContent(obj):
             return []
 
@@ -195,9 +230,11 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             return []
 
         role = args.get('role', obj.getRole())
+        alwaysPresent = [pyatspi.ROLE_PUSH_BUTTON,
+                         pyatspi.ROLE_IMAGE]
 
         if obj.parent and obj.name and obj.name == obj.parent.name \
-           and obj != orca_state.locusOfFocus and role != pyatspi.ROLE_IMAGE:
+           and obj != orca_state.locusOfFocus and role not in alwaysPresent:
             return []
 
         # TODO - JD: Once the formatting strings are vastly cleaned up
@@ -239,6 +276,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return super()._generateLabel(obj, **args)
 
     def _generateNewNodeLevel(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
         if self._script.utilities.isTextBlockElement(obj) \
            or self._script.utilities.isLink(obj):
             return []
@@ -246,6 +286,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return super()._generateNewNodeLevel(obj, **args)
 
     def _generateLeaving(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
         if not args.get('leaving'):
             return []
 
@@ -307,6 +350,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return self._generateDisplayedText(obj, **args)
 
     def _generateRoleName(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
         if not self._script.utilities.inDocumentContent(obj):
             return super()._generateRoleName(obj, **args)
 
